summaryrefslogtreecommitdiffstats
path: root/src/video_core/engines/maxwell_3d.cpp
diff options
context:
space:
mode:
authorZach Hilman <zachhilman@gmail.com>2018-09-01 05:25:18 +0200
committerZach Hilman <zachhilman@gmail.com>2018-09-01 05:25:18 +0200
commitf32e28c7b86ebc0b597ad1a270046c66b097eeb3 (patch)
tree307491a51a6cbd99c102ea2e75ebda42f948c6e5 /src/video_core/engines/maxwell_3d.cpp
parentfilesystem: Implement OpenReadOnlySaveDataFilesystem (diff)
downloadyuzu-f32e28c7b86ebc0b597ad1a270046c66b097eeb3.tar
yuzu-f32e28c7b86ebc0b597ad1a270046c66b097eeb3.tar.gz
yuzu-f32e28c7b86ebc0b597ad1a270046c66b097eeb3.tar.bz2
yuzu-f32e28c7b86ebc0b597ad1a270046c66b097eeb3.tar.lz
yuzu-f32e28c7b86ebc0b597ad1a270046c66b097eeb3.tar.xz
yuzu-f32e28c7b86ebc0b597ad1a270046c66b097eeb3.tar.zst
yuzu-f32e28c7b86ebc0b597ad1a270046c66b097eeb3.zip
Diffstat (limited to 'src/video_core/engines/maxwell_3d.cpp')
-rw-r--r--src/video_core/engines/maxwell_3d.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/video_core/engines/maxwell_3d.cpp b/src/video_core/engines/maxwell_3d.cpp
index 68ff1e86b..e63ad4d46 100644
--- a/src/video_core/engines/maxwell_3d.cpp
+++ b/src/video_core/engines/maxwell_3d.cpp
@@ -5,6 +5,7 @@
#include <cinttypes>
#include "common/assert.h"
#include "core/core.h"
+#include "core/core_timing.h"
#include "core/memory.h"
#include "video_core/debug_utils/debug_utils.h"
#include "video_core/engines/maxwell_3d.h"
@@ -194,8 +195,8 @@ void Maxwell3D::ProcessQueryGet() {
// wait queues.
LongQueryResult query_result{};
query_result.value = result;
- // TODO(Subv): Generate a real GPU timestamp and write it here instead of 0
- query_result.timestamp = 0;
+ // TODO(Subv): Generate a real GPU timestamp and write it here instead of CoreTiming
+ query_result.timestamp = CoreTiming::GetTicks();
Memory::WriteBlock(*address, &query_result, sizeof(query_result));
}
break;